Learn R Programming

geofacet (version 0.1.4)

grids: Geo Grids

Description

See facet_geo for several examples.

us_state_grid1: Grid layout for US states (including DC) Image reference here.

us_state_grid2: Grid layout for US states (including DC) Image reference here.

eu_grid1: Grid layout for the 28 EU Countries Image reference here.

aus_grid1: Grid layout for the Australian States and Territories. Image reference here. Thanks to https://github.com/jonocarroll.

sa_prov_grid1: Grid layout for the provinces of South Africa Image reference here. Thanks to https://github.com/jonmcalder.

london_boroughs_grid: Grid layout for the boroughs of London. Note that the column code_ons contains the codes used by UK Office for National Statistics. Image reference here. Thanks to https://github.com/eldenvo.

nhs_scot_grid: Grid layout for a grid of National Health Service (NHS) Scotland Health Boards. Note that the column code contains the codes used by UK Office for National Statistics. Image reference here. Thanks to https://github.com/josephjosephadams.

india_grid1: Grid layout for India states (not including union territories). Image reference here. Thanks to https://github.com/meysubb.

india_grid2: Grid layout for India states (not including union territories). Image reference here.

argentina_grid1: Grid for the 23 provinces of Argentina. It includes the Malvinas/Falkland Islands and the Antarctic Territories (these are disputed, but they are included since many researchers might use data from these locations). Image reference here. Thanks to https://github.com/eliocamp.

br_grid1: Grid for the 27 states of Brazil. Image reference here. Thanks to https://github.com/italocegatta.

Usage

us_state_grid1

us_state_grid2

eu_grid1

aus_grid1

sa_prov_grid1

london_boroughs_grid

nhs_scot_grid

india_grid1

india_grid2

argentina_grid1

br_grid1

Arguments